<?php
/**
 * OBERONPlugins - Widget class.
 * 
 * This file is part of the OBERON System and WordPress plugins made by Exalogic company and is released under the same license.
 * For more information please see oberon_hotel_reservation_plugin.php.
 * 
 * Copyright (c) 2007-2020 Mário Moravcik. All rights reserved.
 * 
 * Version: 1.0
 * Description:
 * Settings page for wordpress back-office administering of plugin.
 */

if ( ! defined( 'OBERON_PLUGINS_ADMIN_PAGE' ) ) {
	exit;
}

if ( isset( $_POST['oberon-settings-save'] ) ) {
	check_admin_referer( 'oberon-settings-save-order' );
	$this->save_settings();
}

$usrid = get_current_user_id();
$lang = get_user_locale( $usrid );
$lang = substr( $lang, 0, 2 );
if ( !$lang ) {
	$lang = 'en';
}
?>

<div id="eopp-settings" class="wrapper">
	<div class="message-container"></div>
	<h2><?php _e( 'OBERON Plugins', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?></h2>
	<div class="description">
		<?php _e( 'This plugin is a collection of modules for communication with <b>OBERON - Company agenda</b> system via web service API. The plugin uses <b>OBERON Center</b> web service for online communication with company internal system to provide various interfaces like on-line check-in for company customers and users.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
	</div>

	<form id="oberon-settings-admin" action="" method="post">
		<?php wp_nonce_field( 'oberon-settings-save-order' ); ?>
		<div class="eopp-tab">
			<div class="eopp-tab-buttons">

				<p class="tab-submit-top">
					<input class="button button-primary button-large eopp-save" type="submit" name="oberon-settings-save" value="<?php _e( 'Save Changes', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>" />
				</p>
				<h3 class="tab-button active" data-id="eopp-common" tabindex="0">
					<span class="dashicons arrow-close dashicons-arrow-down"></span>
					<span class="dashicons arrow-open dashicons-arrow-right"></span>
					<?php _e( 'Common settings', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
				</h3>
				
				<h3 class="tab-button" data-id="eopp-hotel" tabindex="1">
					<span class="dashicons arrow-close dashicons-arrow-down"></span>
					<span class="dashicons arrow-open dashicons-arrow-right"></span>
					<?php _e( 'Hotel', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
				</h3>
			</div>
			<div class="eopp-tab-pages">
				<div class="tab-page" id="eopp-common">
					<h4>OBERON Center</h4>
					<div class="description">			
						<?php _e( 'OBERON Center is an integral part of OBERON system and is used for background tasks. These include running web services servers used for online communication.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
					</div>
					<h4>OBERON Web</h4>
					<div class="description">
					<?php _e( 'OBERON Web is an online web service module of OBERON Center for communication between system OBERON and its web components or third party services.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
					</div>

					<h4><?php _e( 'How to', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</h4>
					<ol>
						<li><?php _e( 'The most important thing is to ensure that the web service is availabe online for Internet access. This is done with public IP and port configured by the companies ISP (internet services provider).', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?></li>
						<li><?php _e( 'The second major step is to configure internal network and firewalls to allow access from the Internet to the specific port used by OBERON Web service for communication. This should secured by the company internal network administrator.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?></li>
						<li><?php 
							_e( 'The next step (if not already done) is to install new </em>OBERON Web</em> service. Full documentation in slovak language is available in the ', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
							<a href="https://exalogic.sk/help/oberon/index.html#Developers_WebServices_Installation.html" target="_blank"> <?php _e( 'on-line help', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?> </a></li>
					</ol>
					
					<h3><?php _e( 'Basic settings', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</h3>					
					<div class="control">
						<label for="oberon-web-url">OBERON Web - <?php _e( 'web service url', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</label>						
                        <input type="text" id="oberon-web-url" name="oberon-web-url" value="<?php echo esc_url( $this->get_oberon_web_url() ); ?>" />
                        <input class="button-primary button-large eopp-test-connection<?php if(!$this->get_oberon_web_url()) echo ' disabled' ?>" type="button" name="eopp-test-connection" value="<?php _e( 'Test connection', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>" />
					</div>

				</div>
				
				<div class="tab-page hidden" id="eopp-hotel">
					<h3>Online guest pre check-in</h3>
					<div class="description">			
						<?php _e( 'The module is intended for guests to pre-fill their personal data (usualy from home) required for check-in upon arrival at accommodation facility. By filling their data in advance, they can make their check-in process more convenient and faster.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>
					
						<h4><?php _e( 'Add to page', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</h4>
						<ol>
							<li><?php _e( 'Place the following shortcode inside wordpress page (preferred)', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); echo ': [' . OBERON_GuestCheckInWidget::CONST_SHORTCODE_GUESTCHECKIN . ']'; ?> </li>
							<li><?php _e( 'Add widget to the widget panel.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?></li>						
						</ol>
						<h4><?php _e( 'Redirect after successfull submit', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</h4>
						<?php _e( 'After successfull submision of personal data the user can be redirected to a given page.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?> </li>
						<div class="control">
							<label for="oberon-gchi-success-url"><?php _e( 'Url for redirection', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>:</label>
							<input type="text" id="oberon-gchi-success-url" name="gchi-success-url" value="<?php echo esc_url( $this->get_guest_checkin_success_url() ); ?>" />
						</div>
						
					</div>
				</div>
			</div>
		</div>
		<div class="button-list">						
			<input class="button button-primary button-large" type="submit" name="oberon-settings-save" value="<?php _e( 'Save Changes', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ); ?>" />
		</div>
	</form>	
		
	<div class="eopp-settings-message"><!-- only  -->		
		<div class="message-header"></div>
		<div class="message-body">
			<div class="message-row">
				<div class="inner-icon"></div>
				<div class="inner-message">	
				</div>
			</div>
			<div class="button-row"></div>
		</div>
	</div>

</div>

<script type="text/javascript">

(function () {
	jQuery( document ).ready(function(){
				
		jQuery('#eopp-settings').eSettingsPage(
			{ root:		'<?php echo esc_url_raw( rest_url() ) ?>', 
			  nonce: 	'<?php echo wp_create_nonce( 'wp_rest' ) ?>',
			  apiBase: 	'<?php echo $this->get_base_api_path() ?>',
			  version: 	'<?php echo OBERONPlugins_RestController::CONST_REST_VERSION; ?>',
			});

	});
}).call(this);

</script>
