<?php
/**
 * OBERONPlugins_Settings.
 * 
 * This file is part of the OBERON System and WordPress plugins made by Exalogic company and is released under the same license.
 * For more information please see oberon_plugins_plugin.php.
 * 
 * Copyright (c) 2007-2021 Mário Moravcik. All rights reserved.
 * 
 * Description: This class handles options and settings for the plugin.
 * Version: 1.0
 * 
 * Description:
 * Module handles plugin settings.
 */

class OBERONPlugins_Settings {

    const CONST_SERVICE_URL_NAME = 'service-url';
    const CONST_GUEST_CHECKIN_SUCCESS_URL = 'gchi-success-url';

    private $options = array();
    // Control settings used in admin pages
    public $controls = array();


    // --- PUBLIC PROPERTIES ---//
    public $version;
    public $oberon_web_url;
    public $guest_checkin_success_url;
    
    /**
	 * Initialize settings class.
	 */
	public function __construct() {

        if ( is_admin() ) { // In admin we load control settings.
            $this->set_controls();
        }

        // Set defaults
        $this->set_defaults();

	}

    public function load_settings() {

        if ( empty( $this->options ) ) {
			// load if empty.		
			$this->options = get_option( OBERONPlugins::CONST_PLUGIN_OPTION_NAME, $this->get_default_plugin_settings() );
		}

		// load defaults if the options don't exist...
		if ( empty( $this->options ) ) {
			$this->options = $this->get_default_plugin_settings();
		}
        
        if( ! $this->oberon_web_url ) {
            $this->set_defaults();   
        }

        // Load version setting.
        $this->version = get_option( OBERONPlugins::CONST_PLUGIN_OPTION_VERSION, 1 ); //stored version for later updates.

        // Load option settings.
        $this->oberon_web_url = untrailingslashit( $this->options[ OBERONPlugins_Settings::CONST_SERVICE_URL_NAME ] );
        
        $this->guest_checkin_success_url = untrailingslashit( $this->options[ OBERONPlugins_Settings::CONST_GUEST_CHECKIN_SUCCESS_URL ] );

        return true;
    }

    public function save_settings() {

        $defaults = $this->get_default_plugin_settings();
		$this->options = array();   

        // Create settings object.
        $this->options[ OBERONPlugins_Settings::CONST_SERVICE_URL_NAME ] = $this->oberon_web_url;        	

        $this->options[ OBERONPlugins_Settings::CONST_GUEST_CHECKIN_SUCCESS_URL ] = $this->guest_checkin_success_url;


        // Save the new options.
        update_option( OBERONPlugins::CONST_PLUGIN_OPTION_NAME, $this->options );
        
        $this->options = array();
        $this->load_settings(); // Load updated settings

        return true;
    }


    // Set default values for options.
    private function set_defaults() {
        
        $this->version = 1;
        $this->oberon_web_url = '';
        $this->guest_checkin_success_url = '';

    }

    // Set values for controls used in admin pages.
    private function set_controls() {

        $this->controls = (object) array(
			'oberon_web_url' => (object) array(
				'control_id' => 'oberon-web-url',
				'value_type' => 'text',
            ),
            'guest_checkin_success_url' => (object) array(
				'control_id' => 'gchi-success-url',
				'value_type' => 'text',
			),
		);

    }


    // Get default plugin settings.
	function get_default_plugin_settings() {
		return array(
            OBERONPlugins_Settings::CONST_SERVICE_URL_NAME => '',
            OBERONPlugins_Settings::CONST_GUEST_CHECKIN_SUCCESS_URL => '',
		);
	}

}