<?php
/**
 * OBERONPlugins_OnlineCheckIn - Widget class.
 * 
 * This file is part of the OBERON System and WordPress plugins made by Exalogic company and is released under the same license.
 * For more information please see oberon_hotel_reservation_plugin.php.
 * 
 * Copyright (c) 2007-2020 Mário Moravcik. All rights reserved.
 * 
 * Version: 1.0
 * 
 * Description:
 * Widget module for on-line guest check-in.
 */

class OBERON_GuestCheckInWidget extends WP_Widget {

	const CONST_SHORTCODE_GUESTCHECKIN = 'oberon_plugins_guestcheckin';


	private $settings;



	// Regiter widget in Wordpress on new.
	public function __construct() {

		// 
		$widget_ops = array(
			'description' 	=> __( 'On-line form for guests to pre-fill of personal data required for check-in.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ),
		);
		parent::__construct('OBERON_GuestCheckInWidget', // Base ID
							$name = 'OBERON Plugins', 
							$args = $widget_ops );	

		$this->load_settings();
	}

	// Load settings.
	private function load_settings() {
		if( ! isset($this->settings) ) {
			$this->settings = new OBERONPlugins_Settings();	
		}				
		$this->settings->load_settings();				
	}

	// Shared method for shortcode registering.
	public static function register_widget_full($handlerFunctionName) {
		
		register_widget( 'OBERON_GuestCheckInWidget' ); // Must be the same as BaseID in widget.

		add_shortcode( OBERON_GuestCheckInWidget::CONST_SHORTCODE_GUESTCHECKIN, $handlerFunctionName );

    }

	public static function shortcodes_get_baseid($shortcodeTag) {
		
		if ($shortcodeTag == OBERON_GuestCheckInWidget::CONST_SHORTCODE_GUESTCHECKIN ) {
			return 'OBERON_GuestCheckInWidget';
		}

		return '';
    }


	/**
	 * Front-end display of widget.
	 *
	 * @param array $args .
	 * @param array $instance .
	 */
	function widget( $args, $instance ) {
		
		/*
			Widget rendered on page is translated via javascript. It is posible to download also translation files from OBERON.
			That's why here is no translation in html.
		*/
		$this->widget_scripts();
		$this->generate_front_end_html();

	}


	/**
	 * Back-end widget form.
	 *
	 * @param array $instance Previously saved values from database.
	 */
	function form( $instance ) {

		//$restype = $this->validate_reservation_type( $instance['reservation_type'] );
		

		// Formulár pre úpravu priebežných nastavení.

		echo '<div>';
		echo '  <p class="description" style="padding-top: 1em;">';
		echo __( 'OBERON Web service connector version', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ) . ': ' . $this->settings->version;

		echo '  <br />';

		if ( ! $this->settings->oberon_web_url || empty( $this->settings->oberon_web_url ) ) {
			echo __( 'Before using this plugin, the OBERON Web service url have to set in the plugin settings.', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN );
			echo '&nbsp;';
			echo $this->my_settings_link( __( 'settings page', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN ) );
		} else {
			echo __( 'Web service url', OBERONPlugins::CONST_PLUGIN_TEXT_DOMAIN );
			echo ':&nbsp;&nbsp;' . esc_url( $this->settings->oberon_web_url );		
		}
		echo '</p></div>';
	}

	/**
	 * Display of widget with shortcode 'oberon-hotel-reservation-form'.
	 *
	 * @param array $atts Attributes in short code.
	 */
	public function widget_shortcode( $atts ) {

		global $wp_widget_factory;

		$this->widget_scripts();
		$this->generate_front_end_html();

	}

	
    // Register admin scripts.
	function widget_scripts() {
        
        wp_enqueue_style( 'oberon-guestcheckin-styles', OBERONPLUGINS_URL . 'assets/eopp-prod.css', array(), '1.0' );

		wp_enqueue_script( 'eopp-lingua-plugin', OBERONPLUGINS_URL . 'assets/jquery.lingua.min.js', array( 'jquery' ), '1.0', true );
		wp_enqueue_script( 'eopp-application-base', OBERONPLUGINS_URL . 'assets/eopp-application-base.js', array( 'jquery' ), '1.0', true );
		wp_enqueue_script( 'eopp-guestcheckin-script', OBERONPLUGINS_URL . 'assets/eopp-guestcheckin-script.js', array( 'jquery' ), '1.0', true );

    }

	// Generate 
	function generate_front_end_html() {
?>

<div class="oberonbs" id="<?php echo $this->id; ?>">
	<div class="content-body">			
		<div class="online-checkin-content">
			<div class="reservation">
				<div class="container">
					<div class="row">
						<div class="col-10 title"><h4 class="reservationTitle">Rezervácia</h4><h3 class="reservationName"></h3></div>
						<div class="col-2 btn-right">
							<button class="btn btn-flat btnReservationToggle" type="button"></button>
						</div>
					</div>
            		<div class="row form-inline reservation-items" style="display: none;">
						<div class="col-md-6 col-lg-6">
							<div class="form-group itm-eoppDateArrival">
								<label class="col-sm-6 col-form-label">Dátum príchodu:</label>
								<div class="col-sm-6">
									<input type="text" readonly class="form-control-plaintext" id="eoppDateArrival" value="" />
								</div>
							</div>
						</div>
						<div class="col-md-6 col-lg-6">
							<div class="form-group itm-eoppDateDeparture">
								<label class="col-sm-6 col-form-label">Dátum odchodu:</label>
								<div class="col-sm-6">
									<input type="text" readonly class="form-control-plaintext" id="eoppDateDeparture" value="" />
								</div>
							</div>
						</div>
						<div class="col-md-6 col-lg-6">
							<div class="form-group itm-eoppNigthCount">
								<label class="col-sm-6 col-form-label">Počet nocí:</label>
								<div class="col-sm-6">
									<input type="text" readonly class="form-control-plaintext" id="eoppNigthCount" value="" />
								</div>
							</div>
						</div>
						<div class="col-md-4 col-lg-6">
							<div class="form-group itm-eoppPersons">
								<label class="col-sm-6 col-form-label">Osoby:</label>
								<div class="col-sm-6">
									<input type="text" readonly class="form-control-plaintext" id="eoppPersons" value="" />
								</div>
							</div>
						</div>
						<div class="col-md-12 col-lg-12">
							<div class="form-group itm-eoppReservationState">
								<label class="col-sm-6 col-form-label">Stav rezervácie:</label>
								<div class="col-sm-6">
									<input type="text" readonly class="form-control-plaintext" id="eoppReservationState" value="" />
								</div>
							</div>
						</div>						
					</div>
				</div>						
				<div class="eopp-error-panel" style="display: none;">
					<div class="eopp-error-icon"></div>
					<div class="eopp-error-message"></div>
				</div>
			</div>
			<div class="eopp-guests">
			</div>
		</div>	
		<div class="container eopp-buttons" style="display: none;">
			<div class="row">
				<div class="form-group col-md-6 col-lg-9"></div>
				<div class="form-group col-md-6 col-lg-3">
					<button type="submit" id="eopp-submit-checkin" class="btn secondary buttons eopp-submit-checkin">Odoslať</button>
				</div>	
			</div>
		</div>		
	</div>
	<div class="eopp-modal modal" style="display: none;">
		<div class="eopp-modal-backdrop"></div>
		<div class="eopp-modal-dialog">
			<div class="eopp-modal-content">
				<div class="eopp-modal-header">
					<div class="eopp-modal-title"></div>
					<!-- eopp-button-close -->
				</div>
				<div class="eopp-modal-body">
					<div class="eopp-modal-icon"></div>
					<div class="eopp-modal-message"></div>
				</div>
				<div class="eopp-modal-buttons">
					<div class="eopp-modal-ok" style="display: block">
						<button class="btn eopp-button-ok">OK</button>
					</div>
					<div class="eopp-modal-close" style="display: block">
						<button class="btn eopp-button-close">Close</button>
					</div>
				</div>
			</div>
		</div>		
	</div>		
</div>

<script type="text/javascript">

(function() {


	window.guestCheckInWidget = {
		lingua: '<?php echo esc_url( OBERONPLUGINS_URL ); ?>langs/',
		lang: 'sk',
		restUrl: '<?php echo OBERONPlugins_RestController::restUrlBase() ?>',
		guid: '',
		successRedirect: '<?php echo esc_url( $this->settings->guest_checkin_success_url ); ?>',
	};

	<?php
	if (isset($_GET['a'])) {
		?>window.guestCheckInWidget.guid = '<?php echo esc_js($_GET['a']); ?>';<?php
	} else if (isset($_GET['guid'])) {
		?>window.guestCheckInWidget.guid = '<?php echo esc_js($_GET['guid']); ?>';<?php
	}
	if (isset($_GET['lang'])) {
		?>window.guestCheckInWidget.lang = '<?php echo esc_js($_GET['lang']); ?>';<?php
	}
	?>	
	if (!window.guestCheckInWidget.guid || window.guestCheckInWidget.guid.length == 0) {
		var sPageURL = window.location.search.substring(1);
		var sURLVariables = sPageURL.split('&');
		for (var i = 0; i < sURLVariables.length; i++) {
			var sParameterName = sURLVariables[i].split('=');
			if (sParameterName[0] == 'a' || sParameterName[0] == 'guid') {
				window.guestCheckInWidget.guid = sParameterName[1];
			} else if (sParameterName[0] == 'lng' || sParameterName[0] == 'lang') {
				window.guestCheckInWidget.lang = sParameterName[1];
			}
		}	
	}

	
})();

</script>

	<?php

	}


}

?>
